#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_SQRTVALMAX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_SQRTVALMAX_HPP_INCLUDED

#include <boost/simd/constant/include/constants/sqrtvalmax.hpp>

#endif
